@@ -7,17 +7,18 @@ for which a new license (GPL+exception) is in place.
 #ifndef ABOUT_H
 #define ABOUT_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 #include "scribusapi.h"
 
-class TextBrowser; // taken from helpbrowser.h
+class ScTextBrowser;
 class QLabel;
 class QWidget;
-class QHBoxLayout;
-class QVBoxLayout;
 class QTabWidget;
 class QPushButton;
+class QShowEvent;
 
 
 class SCRIBUS_API About : public QDialog
@@ -25,7 +26,14 @@ class SCRIBUS_API About : public QDialog
     	Q_OBJECT
 
 public:
-	About( QWidget* parent );
+
+	typedef enum
+	{
+		Default = 0,
+		CheckUpdates = 1
+	} AboutMode;
+
+	About( QWidget* parent, AboutMode mode = About::Default );
 	~About() {};
 	
 protected:
@@ -39,20 +47,36 @@ protected:
 	QWidget* tab_3;
 	QWidget* tab_4;
 	QWidget* tab_5;
-	TextBrowser* textView1;
-	TextBrowser* textView2;
-	TextBrowser* textView4;
-	TextBrowser* textView5;
+	QWidget* tab_Licence;
+	ScTextBrowser* textView1;
+	ScTextBrowser* textView2;
+	ScTextBrowser* textView4;
+	ScTextBrowser* textView5;
+	ScTextBrowser* textViewLicence;
 	QVBoxLayout* aboutLayout;
 	QVBoxLayout* updateLayout;
+	QVBoxLayout* licenceLayout;
 	QHBoxLayout* tabLayout;
 	QVBoxLayout* tabLayout1;
 	QHBoxLayout* tabLayout_2;
 	QHBoxLayout* tabLayout_4;
 	QHBoxLayout* layout2;
 
+	bool         m_firstShow;
+	AboutMode    m_mode;
+	virtual void showEvent ( QShowEvent * event ); 
+    QString trAuthorTitle(QString title);
+    QString trTranslationTitle(QString title);
+    QString trLinksTitle(QString title);
+    QString parseAuthorFile(QString fileName);
+    QString parseTranslationFile(QString fileName);
+    QString parseLinksFile(QString fileName);
+
 protected slots:
 	void runUpdateCheck();
+
+public slots:
+	virtual void setVisible (bool visible); 
 };
 
 #endif // ABOUT_H
