@@ -7,23 +7,20 @@ for which a new license (GPL+exception) is in place.
 #ifndef PAGESELECTOR_H
 #define PAGESELECTOR_H
 
+#include <QWidget>
 
-#include "styleoptions.h"
-
-#include <qvariant.h>
-#include <qpixmap.h>
-#include <qwidget.h>
-#include <qvalidator.h>
-#include "scribusapi.h"
-
-class QVBoxLayout;
+class QEvent;
 class QHBoxLayout;
-class QGridLayout;
-class QComboBox;
+class QLabel;
 class QLineEdit;
-class QPopupMenu;
 class QPushButton;
 class QToolButton;
+class QIntValidator;
+
+#include "scribusapi.h"
+#include "styleoptions.h"
+
+class ScComboBox;
 
 class SCRIBUS_API PageSelector : public QWidget
 {
@@ -32,8 +29,12 @@ class SCRIBUS_API PageSelector : public QWidget
 public:
 	PageSelector( QWidget* parent, int maxPg );
 	~PageSelector() {};
+	
+	virtual void changeEvent(QEvent *e);
+	
 	bool hasFocus();
-	void focusPolicy(QWidget::FocusPolicy policy);
+	void focusPolicy(Qt::FocusPolicy policy);
+	void setFont ( const QFont & );
 
 #if OPTION_USE_QTOOLBUTTON
 	QToolButton* Start;
@@ -47,14 +48,14 @@ public:
 	QPushButton* Last;
 #endif
 	
-	QComboBox* PageCombo;
-	QValidator *v;
+	ScComboBox* PageCombo;
+	QIntValidator *m_validator;
 	int LastPG;
 	int APage;
 
 public slots:
 	virtual void GotoPg(int);
-	virtual void setMaxValue(int);
+	virtual void setMaximum(int);
 	void languageChange();
 	void clearFocus();
 
@@ -68,6 +69,8 @@ private slots:
 
 protected:
 	QHBoxLayout* PageSelectorLayout;
+	QLabel *PageCount;
+	QString PageCountString;
 
 signals:
 	void GotoPage(int);
